@@ -7,12 +7,12 @@
 # - call 'Convertgmodels1.sh' to convert special characters
 #
 # Author:   Georg Fleischmann
-# modified: 2004-10-06
+# modified: 2006-06-08
 #
 
 PROJECTS=~/Projects
 ASTRO=$PROJECTS/Cenon/Source/Astro
-Cenon=$PROJECTS/Cenon/Source/Cenon
+CENON=$PROJECTS/Cenon/Source/Cenon
 
 cd $ASTRO
 
@@ -21,14 +21,25 @@ do
 
     # EventPanel, CityPanel, TimeZonePanel
     echo $lng.lproj/EventPanel.nib
-    nib2gmodel $lng.lproj/EventPanel.nib $lng.lproj/EventPanel.gmodel
-    nib2gmodel $lng.lproj/CityPanel.nib $lng.lproj/CityPanel.gmodel
+    nib2gmodel $lng.lproj/EventPanel.nib    $lng.lproj/EventPanel.gmodel
+    nib2gmodel $lng.lproj/CityPanel.nib     $lng.lproj/CityPanel.gmodel
     nib2gmodel $lng.lproj/TimeZonePanel.nib $lng.lproj/TimeZonePanel.gmodel
 
     # Astro.prefs
-    FILE=Astro.bproj/$lng.lproj/Astro
-    echo $FILE.nib
-    nib2gmodel $FILE.nib $FILE.gmodel
+    for nib in Astro AstroGeneral AstroObjects AstroChart
+    do
+        FILE=Astro.bproj/$lng.lproj/$nib
+        if [ -d $FILE.nib ]; then
+          echo $FILE.nib
+          ln -s $ASTRO/Astro.bproj/[apm]*.tiff $FILE.nib/
+          #ln -s $CENON/arrow*.tiff $FILE.nib/
+          nib2gmodel $FILE.nib $FILE.gmodel
+          rm $FILE.nib/[apm]*.tiff
+        fi
+    done
+    #FILE=Astro.bproj/$lng.lproj/Astro
+    #echo $FILE.nib
+    #nib2gmodel $FILE.nib $FILE.gmodel
 
     # AstroPanel
     for nib in AstroPanelTab APChart APMap APSearch
@@ -36,7 +47,7 @@ do
         FILE=AstroPanel.subproj/$lng.lproj/$nib
         if [ -d $FILE.nib ]; then
           echo $FILE.nib
-          ln -s $Cenon/arrow*.tiff $FILE.nib/
+          ln -s $CENON/arrow*.tiff $FILE.nib/
           nib2gmodel $FILE.nib $FILE.gmodel
           rm $FILE.nib/arrow*.tiff
         fi
